@@ -5,4 +5,4 @@
 # SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 
-$XGETTEXT `find . -name \*.qml -or -name \*.cpp` -o $podir/skanpage.pot
+$XGETTEXT `find . \( -name "*.qml" -or -name "*.cpp" -or -name "*.h" \)` -o $podir/skanpage.pot
